pub struct Config {Show 17 fields
pub username: String,
pub password: String,
pub smtp_server: String,
pub smtp_port: u16,
pub smtp_check_timeout: Option<u64>,
pub message: String,
pub message_warning: String,
pub subject: String,
pub subject_warning: String,
pub to: String,
pub from: String,
pub attachment: Option<String>,
pub timer_warning: u64,
pub timer_dead_man: u64,
pub web_password: String,
pub cookie_exp_days: u64,
pub log_level: Option<String>,
}Expand description
Configuration struct used for the application
Default
If the configuration file does not exist, it will be created with the default values.
Fields
username: StringThe username for the email account.
password: StringThe password for the email account.
smtp_server: StringThe SMTP server to use
smtp_port: u16The port to use for the SMTP server.
smtp_check_timeout: Option<u64>The timeout to use for the SMTP server.
message: StringThe message to send in the email if you fail to check in
after the timer_warning with the additional timer_dead_man
seconds have passed.
message_warning: StringThe warning message if you fail to check in timer_warning seconds.
subject: StringThe subject of the email if you fail to check in
after the timer_warning with the additional timer_dead_man
seconds have passed.
subject_warning: StringThe subject of the email if you fail to check in timer_warning seconds.
to: StringThe email address to send the email to.
from: StringThe email address to send the email from.
attachment: Option<String>Attachment to send with the email.
timer_warning: u64Timer in seconds for the warning email.
timer_dead_man: u64Timer in seconds for the dead man’s email.
web_password: StringWeb interface password
Cookie expiration to avoid need for login
log_level: Option<String>Log level for the web interface.